# CHANGELOG

## v0.1.0 (2024-07-19)

### Chore

* chore: add python semantic release ([`f64b54c`](https://github.com/adfinis/django-presigned-url/commit/f64b54c04851bef5ff2f9196e1397e5f7f98239c))

* chore: add GPLv3 license ([`881420a`](https://github.com/adfinis/django-presigned-url/commit/881420a645c1f389278165a6e165b8c878228cb1))

### Feature

* feat: implement django-presigned-url ([`f47dc85`](https://github.com/adfinis/django-presigned-url/commit/f47dc8581d6d36e9bdb82ba4bdba3e0fefb50b54))
